@@ -607,6 +607,7 @@ onBroadcast(msg => {
         const url = new URL(options.docURL);
         comment = '! ' +
             this.hiddenSettings.autoCommentFilterTemplate
+                .replace('{{isodate}}', d.toISOString().split('T')[0])
                 .replace('{{date}}', d.toLocaleDateString(undefined, { dateStyle: 'medium' }))
                 .replace('{{time}}', d.toLocaleTimeString())
                 .replace('{{hostname}}', url.hostname)
@@ -1007,12 +1008,12 @@ onBroadcast(msg => {
         ubolog('loadFilterLists() Start');
         t0 = Date.now();
         loadedListKeys.length = 0;
-        loadingPromise = Promise.all([
-            this.getAvailableLists().then(lists => onFilterListsReady(lists)),
-            this.loadRedirectResources().then(( ) => {
-                ubolog(`loadFilterLists() Redirects/scriptlets ready at ${elapsed()}`);
-            }),
-        ]).then(( ) => {
+        loadingPromise = this.loadRedirectResources().then(( ) => {
+            ubolog(`loadFilterLists() Redirects/scriptlets ready at ${elapsed()}`);
+            return this.getAvailableLists();
+        }).then(lists => {
+            return onFilterListsReady(lists)
+        }).then(( ) => {
             onDone();
         });
         return loadingPromise;
