@@ -19,29 +19,23 @@
     Home: https://github.com/gorhill/uBlock
 */
 
-/* globals browser */
-
-'use strict';
-
 /******************************************************************************/
 
-import htmlFilteringEngine from './html-filtering.js';
-import httpheaderFilteringEngine from './httpheader-filtering.js';
-import logger from './logger.js';
-import scriptletFilteringEngine from './scriptlet-filtering.js';
-import staticNetFilteringEngine from './static-net-filtering.js';
-import textEncode from './text-encode.js';
-import µb from './background.js';
-import * as sfp from './static-filtering-parser.js';
 import * as fc from  './filtering-context.js';
-import { isNetworkURI } from './uri-utils.js';
-
+import * as sfp from './static-filtering-parser.js';
 import {
     sessionFirewall,
     sessionSwitches,
     sessionURLFiltering,
 } from './filtering-engines.js';
-
+import htmlFilteringEngine from './html-filtering.js';
+import httpheaderFilteringEngine from './httpheader-filtering.js';
+import { isNetworkURI } from './uri-utils.js';
+import logger from './logger.js';
+import scriptletFilteringEngine from './scriptlet-filtering.js';
+import staticNetFilteringEngine from './static-net-filtering.js';
+import textEncode from './text-encode.js';
+import µb from './background.js';
 
 /******************************************************************************/
 
@@ -559,11 +553,16 @@ const onHeadersReceived = function(details) {
     if ( httpheaderFilteringEngine.apply(fctxt, responseHeaders) === true ) {
         modifiedHeaders = true;
     }
-    if ( injectCSP(fctxt, pageStore, responseHeaders) === true ) {
-        modifiedHeaders = true;
-    }
-    if ( injectPP(fctxt, pageStore, responseHeaders) === true ) {
-        modifiedHeaders = true;
+
+    // https://github.com/uBlockOrigin/uBlock-issues/issues/229#issuecomment-2220354261
+    // Inject CSP/PP in document resource only
+    if ( fctxt.isDocument() ) {
+        if ( injectCSP(fctxt, pageStore, responseHeaders) === true ) {
+            modifiedHeaders = true;
+        }
+        if ( injectPP(fctxt, pageStore, responseHeaders) === true ) {
+            modifiedHeaders = true;
+        }
     }
 
     // https://bugzilla.mozilla.org/show_bug.cgi?id=1376932
@@ -590,7 +589,7 @@ const onHeadersReceived = function(details) {
     }
 };
 
-const reMediaContentTypes = /^(?:audio|image|video)\//;
+const reMediaContentTypes = /^(?:audio|image|video)\/|(?:\/ogg)$/;
 
 /******************************************************************************/
 
@@ -695,7 +694,7 @@ const bodyFilterer = (( ) => {
         'audio/x-mpegurl',
     ]);
     const BINARY_TYPES = fc.FONT | fc.IMAGE | fc.MEDIA | fc.WEBSOCKET;
-    const MAX_BUFFER_LENGTH = 3 * 1024 * 1024;
+    const MAX_RESPONSE_BUFFER_LENGTH = 10 * 1024 * 1024;
 
     let textDecoder, textEncoder;
     let mime = '';
@@ -703,12 +702,12 @@ const bodyFilterer = (( ) => {
 
     const contentTypeFromDetails = details => {
         switch ( details.type ) {
-            case 'script':
-                return 'text/javascript; charset=utf-8';
-            case 'stylesheet':
-                return 'text/css';
-            default:
-                break;
+        case 'script':
+            return 'text/javascript; charset=utf-8';
+        case 'stylesheet':
+            return 'text/css';
+        default:
+            break;
         }
         return '';
     };
@@ -721,13 +720,13 @@ const bodyFilterer = (( ) => {
 
     const charsetFromMime = mime => {
         switch ( mime ) {
-            case 'application/xml':
-            case 'application/xhtml+xml':
-            case 'text/html':
-            case 'text/css':
-                return;
-            default:
-                break;
+        case 'application/xml':
+        case 'application/xhtml+xml':
+        case 'text/html':
+        case 'text/css':
+            return;
+        default:
+            break;
         }
         return 'utf-8';
     };
@@ -749,7 +748,7 @@ const bodyFilterer = (( ) => {
             /* t */ if ( bytes[i+6] !== 0x74 ) { continue; }
             break;
         }
-        if ( (i - 40) >= 65536 ) { return; }
+        if ( (i + 40) >= 65536 ) { return; }
         i += 8;
         // find first alpha character
         let j = -1;
@@ -811,7 +810,7 @@ const bodyFilterer = (( ) => {
         buffer.set(session.buffer);
         buffer.set(new Uint8Array(ev.data), session.buffer.byteLength);
         session.buffer = buffer;
-        if ( session.buffer.length >= MAX_BUFFER_LENGTH ) {
+        if ( session.buffer.length >= MAX_RESPONSE_BUFFER_LENGTH ) {
             sessions.delete(this);
             this.write(session.buffer);
             this.disconnect();
@@ -827,13 +826,17 @@ const bodyFilterer = (( ) => {
         }
         if ( this.status !== 'finishedtransferringdata' ) { return; }
 
-        // If encoding is still unknown, try to extract from stream data
+        // If encoding is still unknown, try to extract from stream data.
+        // Just assume utf-8 if ultimately no encoding can be looked up.
         if ( session.charset === undefined ) {
             const charsetFound = charsetFromStream(session.buffer);
-            if ( charsetFound === undefined ) { return streamClose(session); }
-            const charsetUsed = textEncode.normalizeCharset(charsetFound);
-            if ( charsetUsed === undefined ) { return streamClose(session); }
-            session.charset = charsetUsed;
+            if ( charsetFound !== undefined ) {
+                const charsetUsed = textEncode.normalizeCharset(charsetFound);
+                if ( charsetUsed === undefined ) { return streamClose(session); }
+                session.charset = charsetUsed;
+            } else {
+                session.charset = 'utf-8';
+            }
         }
 
         while ( session.jobs.length !== 0 ) {
